@@ -1,4 +1,4 @@
-// $Id: vserver-internal.h,v 1.14 2004/02/04 23:38:39 ensc Exp $    --*- c++ -*--
+// $Id: vserver-internal.h,v 1.15 2004/02/13 23:43:19 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -31,8 +31,8 @@
 
 #include "internal.h"
 
-#ifndef __NR_vserver
-#  define __NR_vserver	273
+#if !defined(__NR_vserver) && defined(ENSC_SYSCALL__NR_vserver)
+#  define __NR_vserver	ENSC_SYSCALL__NR_vserver
 #endif
 
 #define VC_PREFIX	0)
