@@ -1,4 +1,4 @@
-// $Id: secure-mount.c,v 1.10 2004/02/10 17:05:36 ensc Exp $    --*- c++ -*--
+// $Id: secure-mount.c,v 1.11 2004/02/16 19:14:01 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -94,6 +94,10 @@ CMDLINE_OPTIONS[] = {
   { 0, 0, 0, 0 }
 };
 
+#ifndef MS_REC
+#  define MS_REC	0x4000
+#endif
+
 static struct FstabOptions {
     char const * const	opt;
     unsigned long const	or_flag;
