@@ -1,4 +1,4 @@
-// $Id: setattr.c,v 1.7 2004/02/05 22:16:09 ensc Exp $    --*- c -*--
+// $Id: setattr.c,v 1.9 2004/02/19 22:29:20 ensc Exp $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -88,17 +88,16 @@ fixupParams(struct Arguments * args, int argc)
   }
 
   args->do_display_dir = !args->do_recurse;
+  args->do_display_dot = true;
 }
 
 bool
-handleFile(char const *name, char const * display_name,
-	   struct stat const *exp_st)
+handleFile(char const *name, char const * display_name)
 {
-  int rc = vc_set_iattr_compat(name, exp_st->st_dev, exp_st->st_ino,
-			       0,
-			       global_args->set_mask & ~global_args->del_mask,
-			       global_args->set_mask |  global_args->del_mask,
-			       &exp_st->st_mode);
+  int rc = vc_set_iattr(name,
+			0,
+			global_args->set_mask & ~global_args->del_mask,
+			global_args->set_mask |  global_args->del_mask);
 
   if (rc==-1) {
     perror(display_name);
