@@ -1,4 +1,4 @@
-// $Id: util.h,v 1.7 2004/02/06 21:34:10 ensc Exp $    --*- c++ -*--
+// $Id: util.h,v 1.9 2004/02/18 04:45:26 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -20,6 +20,10 @@
 #define H_UTIL_VSERVER_SRC_UTIL_H
 
 #include "compat.h"
+#include "lib_internal/util-io.h"
+#include "lib_internal/util-mem.h"
+#include "lib_internal/util-safechdir.h"
+#include "lib_internal/util-dotfile.h"
 
 #include <unistd.h>
 #include <string.h>
@@ -47,26 +51,8 @@
 
 #define DIM_OF(X)		(sizeof(X)/sizeof((X)[0]))
 
-inline static void *
-Xmemcpy(void * restrict dst, void const * restrict src, size_t len)
-{
-  memcpy(dst, src, len);
-  return (char *)(dst)+len;
-}
-
-inline static void UNUSED
-writeStr(int fd, char const *cmd)
-{
-  (void)write(fd, cmd, strlen(cmd));
-}
-
-struct stat;
-int	safeChdir(char const *, struct stat const *exp_stat) NONNULL((1,2));
-
 void	exitLikeProcess(int pid) NORETURN;
 
-#define WRITE_MSG(FD,X)		(void)(write(FD,X,sizeof(X)-1))
-#define WRITE_STR(FD,X)		writeStr(FD,X)
 
 #define VSERVER_DECLARE_CMD(CMD)     \
   char		buf[strlen(CMD)+1];  \
